==> mingw-w64-ossia-score-3.2.1-1.src.tar.zst: ossia-score-3.2.1/src/lib/score/graphics/widgets/QGraphicsLogKnob.hpp <==
#pragma once
#include <score/graphics/widgets/Constants.hpp>

#include <QGraphicsItem>
#include <QObject>

#include <score_lib_base_export.h>

#include <verdigris>

namespace score
{
class SCORE_LIB_BASE_EXPORT QGraphicsLogKnob final
    : public QObject
    , public QGraphicsItem
{
  W_OBJECT(QGraphicsLogKnob)
  Q_INTERFACES(QGraphicsItem)
  friend struct DefaultGraphicsKnobImpl;

  double m_value{};
  double m_execValue{};
  QRectF m_rect{defaultKnobSize};

public:
  double min{}, max{};

private:
  bool m_grab{};
  bool m_hasExec{};

public:
  QGraphicsLogKnob(QGraphicsItem* parent);

  double map(double v) const noexcept;
  double unmap(double v) const noexcept;

  void setRect(const QRectF& r);
  void setRange(double min, double max);
  void setValue(double v);
  double value() const;
  void setExecutionValue(double v);
  void resetExecution();

  QRectF boundingRect() const override;

  bool moving = false;

public:
  void sliderMoved() E_SIGNAL(SCORE_LIB_BASE_EXPORT, sliderMoved)
  void sliderReleased() E_SIGNAL(SCORE_LIB_BASE_EXPORT, sliderReleased)

private:
  void mousePressEvent(QGraphicsSceneMouseEvent* event) override;
  void mouseMoveEvent(QGraphicsSceneMouseEvent* event) override;
  void mouseReleaseEvent(QGraphicsSceneMouseEvent* event) override;
  void contextMenuEvent(QGraphicsSceneContextMenuEvent* event) override;
  void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event) override;

  void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget)
      override;
};
}

==> mingw-w64-ossia-score-3.5.1-1.src.tar.zst: ossia-score-3.5.1/src/lib/score/graphics/widgets/QGraphicsLogKnob.hpp <==
#pragma once
#include <score/graphics/widgets/Constants.hpp>

#include <QGraphicsItem>
#include <QObject>

#include <score_lib_base_export.h>

#include <verdigris>

namespace score
{
class SCORE_LIB_BASE_EXPORT QGraphicsLogKnob final
    : public QObject
    , public QGraphicsItem
{
  W_OBJECT(QGraphicsLogKnob)
  SCORE_GRAPHICS_ITEM_TYPE(90)
  friend struct DefaultControlImpl;
  friend struct DefaultGraphicsKnobImpl;

  double m_value{};
  double m_execValue{};
  QRectF m_rect{defaultKnobSize};

public:
  double min{}, max{}, init{};

private:
  bool m_grab{};
  bool m_hasExec{};

public:
  explicit QGraphicsLogKnob(QGraphicsItem* parent);
  ~QGraphicsLogKnob();

  double map(double v) const noexcept;
  double unmap(double v) const noexcept;

  void setRect(const QRectF& r);
  void setRange(double min, double max, double init);
  void setValue(double v);
  double value() const;
  void setExecutionValue(double v);
  void resetExecution();

  QRectF boundingRect() const override;

  bool moving = false;

public:
  void sliderMoved() E_SIGNAL(SCORE_LIB_BASE_EXPORT, sliderMoved)
  void sliderReleased() E_SIGNAL(SCORE_LIB_BASE_EXPORT, sliderReleased)

private:
  void mousePressEvent(QGraphicsSceneMouseEvent* event) override;
  void mouseMoveEvent(QGraphicsSceneMouseEvent* event) override;
  void mouseReleaseEvent(QGraphicsSceneMouseEvent* event) override;
  void contextMenuEvent(QGraphicsSceneContextMenuEvent* event) override;
  void mouseDoubleClickEvent(QGraphicsSceneMouseEvent* event) override;

  void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget)
      override;
};
}
